summaryrefslogtreecommitdiffstats
path: root/chrome/views/chrome_menu.h
diff options
context:
space:
mode:
authorsky@google.com <sky@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-09-08 14:46:36 +0000
committersky@google.com <sky@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-09-08 14:46:36 +0000
commit2e1f49096ed49419de8c740a20ab106c14ffbf44 (patch)
tree787ff8465a8c859105a38b155ce89057c13ea8ce /chrome/views/chrome_menu.h
parent30039e6ec600f1ac2a34e0881f4c0c10ee6f80cd (diff)
downloadchromium_src-2e1f49096ed49419de8c740a20ab106c14ffbf44.zip
chromium_src-2e1f49096ed49419de8c740a20ab106c14ffbf44.tar.gz
chromium_src-2e1f49096ed49419de8c740a20ab106c14ffbf44.tar.bz2
This patch is from Andrew Brampton <me@bramp.net>.
This patches allows menu items in PopUpMenus to be clicked with the right mouse button. menu.cc controls the web content popup menus, and some others chrome_menu{.cc,.h} controls popup menu on the chrome, for example right clicking on a tab. BUG=718 TEST=Bring up any menu (wrench/document) and right click on one of the items. This should select the item. Try the same with any of the bookmark menus. git-svn-id: svn://svn.chromium.org/chrome/trunk/src@1838 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/views/chrome_menu.h')
-rw-r--r--chrome/views/chrome_menu.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/chrome/views/chrome_menu.h b/chrome/views/chrome_menu.h
index a017b3d..05cce11 100644
--- a/chrome/views/chrome_menu.h
+++ b/chrome/views/chrome_menu.h
@@ -72,11 +72,13 @@ class MenuDelegate : Controller {
// If this is not the result of a mouse gesture x/y is the recommended
// location to display the content menu at. In either case, x/y is in
// screen coordinates.
- virtual void ShowContextMenu(MenuItemView* source,
+ // Returns true if a context menu was displayed, otherwise false
+ virtual bool ShowContextMenu(MenuItemView* source,
int id,
int x,
int y,
bool is_mouse_gesture) {
+ return false;
}
// Controller
@@ -101,9 +103,9 @@ class MenuDelegate : Controller {
}
// Returns true if the specified mouse event is one the user can use
// to trigger, or accept, the mouse. Defaults to only left mouse buttons.
virtual bool IsTriggerableEvent(const MouseEvent& e) {
- return e.IsLeftMouseButton();
+ return e.IsLeftMouseButton() || e.IsRightMouseButton();
}
// Invoked to determine if drops can be accepted for a submenu. This is
@@ -101,9 +103,9 @@ class MenuDelegate : Controller {
}
// Returns true if the specified mouse event is one the user can use
- // to trigger, or accept, the mouse. Defaults to only left mouse buttons.
+ // to trigger, or accept, the mouse. Defaults to left or right mouse buttons.
virtual bool IsTriggerableEvent(const MouseEvent& e) {